'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _rfr = require('rfr');

var _rfr2 = _interopRequireDefault(_rfr);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var debug = (0, _debug2.default)('quture:config');

/**
 *
 */

var Config = function () {

  /**
   * Create a new Config instance.
   *
   * @param {object} options
   * @returns {Config}
   * @throws {Error} if a configuration option is not a valid option
   */
  function Config(options) {
    _classCallCheck(this, Config);

    if (options.configDir && typeof options.configDir === 'string') {
      this._configDir = options.configDir;
      this._rfr = (0, _rfr2.default)({ root: this._configDir });
    } else {
      throw new Error('{options.configDir} is required');
    }
  }

  /**
   * Retrieve the path to the config directory.
   *
   * @returns {string}
   */


  _createClass(Config, [{
    key: 'getConfigDirectory',
    value: function getConfigDirectory() {
      return this._configDir;
    }

    /**
     * Get a value from an object specified within a file.
     *
     * @param {string} fileName
     * @param {string} defaultValue
     * @returns value
     */

  }, {
    key: 'get',
    value: function get(fileName, defaultValue) {
      var fileNameSplit = fileName.split('.');
      var value = null;
      try {
        debug('Attempting to load a configuration value from ' + fileNameSplit[0]);
        var file = this._rfr(fileNameSplit[0]);
        value = file;
        for (var i = 1; i < fileNameSplit.length; i++) {
          var exists = false;
          if (i === 1) {
            if (fileNameSplit[i] != null) {
              value = file[fileNameSplit[i]];
              exists = true;
            }
          } else {
            if (value != null) {
              if (fileNameSplit[i] != null) {
                value = value[fileNameSplit[i]];
                exists = true;
              }
            }
          }

          if (exists) {
            debug('Configuration value loaded from \'' + fileNameSplit[0] + '\'');
            break;
          }

          if (!exists) {
            debug('\'' + fileNameSplit[0] + '\' doesn\'t exist within \'' + fileName);
            break;
          }
        }
      } catch (e) {
        debug(e);
        debug('Unable to load file with the name \'' + fileNameSplit[0] + '\'');
      }

      if (value && typeof value === 'string') {
        value = value.toLowerCase() === 'true' || value.toLowerCase() === 'false' ? value.toLowerCase() === 'true' ? true : false : value;
      }

      return value !== undefined && value !== null ? value : defaultValue;
    }

    /**
     * Check if the specified path exists.
     *
     * @param {string} configPath
     * @returns {boolean}
     */

  }, {
    key: 'has',
    value: function has(configPath) {
      return this.get(configPath) !== null && this.get(configPath) !== undefined;
    }
  }]);

  return Config;
}();

exports.default = Config;
module.exports = exports['default'];