'use strict';

import path from 'path';
import Config from '../src/config';

/**
 * Unit tests.
 */
describe('quture-config', function() {

  it('should not create a new {Config} instance without the {options.configDir} parameter', function(done) {
    try {
      let config = new Config();
      done(new Error('A new {Config} instance was created'));
    } catch (error) {
      done();
    }
  });

  it('should create a new {Config} instance with the {options.configDir} parameter', function(done) {
    try {
      let config = new Config({
        configDir: path.join(__dirname, 'config')
      });
      done();
    } catch (error) {
      done(error);
    }
  });

  it('should not load an unknown value from the config file', function(done) {
    try {
      let config = new Config({
        configDir: path.join(__dirname, 'config')
      });

      if (config.has('app.unknown')) {
        done(new Error('{app.unknown} has the value of ' + config.get('app.unknown')));
      } else {
        done();
      }
    } catch (error) {
      done(error);
    }
  });

  it('should load an known value from the config file', function(done) {
    try {
      let config = new Config({
        configDir: path.join(__dirname, 'config')
      });

      if (config.has('app.planet')) {
        done();
      } else {
        done(new Error('{app.planet} could not be found'))
      }
    } catch (error) {
      done(error);
    }
  });

  it('should parse a boolean string as a boolean type from the config', function(done) {
    try {
      let config = new Config({
        configDir: path.join(__dirname, 'config')
      });

      if (config.get('app.booleanTest') === true) {
        done();
      } else {
        done(new Error('{app.booleanTest} could not be found'))
      }
    } catch (error) {
      done(error);
    }
  });

});
